==> docfbe_2_3_36_63.zip: docfbe_2_3_36_63/source/TCFbERotatedTableEx.cpp <==
/*
    TCFbERotatedTableEx.cpp    December 4, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbERotatedTableEx.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^iLbV쐬
__fastcall TCFbERotatedTableEx::TCFbERotatedTableEx(void)
    : TCFbECustomTableEx()
{
}

//---------------------------------------------------------------------------
// w肳ꂽse[u쐬
__fastcall TCFbERotatedTableEx::TCFbERotatedTableEx(TStringList* RowLabelList, TStringList* ColumnLabelList)
    : TCFbECustomTableEx(RowLabelList, ColumnLabelList)
{
}

//---------------------------------------------------------------------------
// RXgN^
__fastcall TCFbERotatedTableEx::TCFbERotatedTableEx(TStringList* SourceCsvStringList)
    : TCFbECustomTableEx(SourceCsvStringList)
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbERotatedTableEx::~TCFbERotatedTableEx()
{
}

//---------------------------------------------------------------------------
// eLbṼZXVꂽ
void __fastcall TCFbERotatedTableEx::ParentCellIsUpdated(int RowIndex, int ColumnIndex)
{
    TCFbECustomTableEx::ParentCellIsUpdated(ColumnIndex, RowIndex);
}

//---------------------------------------------------------------------------
// eLbV̍sǉꂽ
int __fastcall  TCFbERotatedTableEx::ParentAddRow(AnsiString RowLabel)
{
    return this->AddColumn(RowLabel);
}

//---------------------------------------------------------------------------
// eLbV̗񂪒ǉꂽ
int __fastcall  TCFbERotatedTableEx::ParentAddColumn(AnsiString ColumnLabel)
{
    return this->AddRow(ColumnLabel);
}

//---------------------------------------------------------------------------
// eLbV̍s폜ꂽ
void __fastcall TCFbERotatedTableEx::ParentDeleteRowByIndex(int TargetRowIndex)
{
    this->DeleteColumnByIndex(TargetRowIndex);
}

//---------------------------------------------------------------------------
// eLbV̗񂪍폜ꂽ
void __fastcall TCFbERotatedTableEx::ParentDeleteColumnByIndex(int TargetColumnIndex)
{
    this->DeleteRowByIndex(TargetColumnIndex);
}

//---------------------------------------------------------------------------
// ȉCprotected method
//---------------------------------------------------------------------------
// g̃N[쐬
TCFbECachedTable* __fastcall TCFbERotatedTableEx::CreateClone(void)
{
    TCFbERotatedTableEx* Clone = new TCFbERotatedTableEx();
    Clone->Assign(this);
    return Clone;
}

//---------------------------------------------------------------------------
// g̍sƗ񂪓ւN[쐬
TCFbECachedTable* __fastcall TCFbERotatedTableEx::CreateRotatedClone(void)
{
    TCFbETableEx* Clone = new TCFbETableEx();
    Clone->RotatedAssign(this);
    return Clone;
}

//---------------------------------------------------------------------------

==> docfbe_2_3_39_68.zip: docfbe_2_3_39_68/source/TCFbERotatedTableEx.cpp <==
/*
    TCFbERotatedTableEx.cpp    December 4, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbERotatedTableEx.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^iLbV쐬
__fastcall TCFbERotatedTableEx::TCFbERotatedTableEx(void)
    : TCFbECustomTableEx()
{
}

//---------------------------------------------------------------------------
// w肳ꂽse[u쐬
__fastcall TCFbERotatedTableEx::TCFbERotatedTableEx(TStringList* RowLabelList, TStringList* ColumnLabelList)
    : TCFbECustomTableEx(RowLabelList, ColumnLabelList)
{
}

//---------------------------------------------------------------------------
// RXgN^
__fastcall TCFbERotatedTableEx::TCFbERotatedTableEx(TStringList* SourceCsvStringList)
    : TCFbECustomTableEx(SourceCsvStringList)
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbERotatedTableEx::~TCFbERotatedTableEx()
{
}

//---------------------------------------------------------------------------
// eLbṼZXVꂽ
void __fastcall TCFbERotatedTableEx::ParentCellIsUpdated(int RowIndex, int ColumnIndex)
{
    TCFbECustomTableEx::ParentCellIsUpdated(ColumnIndex, RowIndex);
}

//---------------------------------------------------------------------------
// eLbV̍sǉꂽ
int __fastcall  TCFbERotatedTableEx::ParentAddRow(const char* RowLabel)
{
    return this->AddColumn(RowLabel);
}

//---------------------------------------------------------------------------
// eLbV̗񂪒ǉꂽ
int __fastcall  TCFbERotatedTableEx::ParentAddColumn(const char* ColumnLabel)
{
    return this->AddRow(ColumnLabel);
}

//---------------------------------------------------------------------------
// eLbV̍s폜ꂽ
void __fastcall TCFbERotatedTableEx::ParentDeleteRowByIndex(int TargetRowIndex)
{
    this->DeleteColumnByIndex(TargetRowIndex);
}

//---------------------------------------------------------------------------
// eLbV̗񂪍폜ꂽ
void __fastcall TCFbERotatedTableEx::ParentDeleteColumnByIndex(int TargetColumnIndex)
{
    this->DeleteRowByIndex(TargetColumnIndex);
}

//---------------------------------------------------------------------------
// ȉCprotected method
//---------------------------------------------------------------------------
// g̃N[쐬
TCFbECachedTable* __fastcall TCFbERotatedTableEx::CreateClone(void)
{
    TCFbERotatedTableEx* Clone = new TCFbERotatedTableEx();
    Clone->Assign(this);
    return Clone;
}

//---------------------------------------------------------------------------
// g̍sƗ񂪓ւN[쐬
TCFbECachedTable* __fastcall TCFbERotatedTableEx::CreateRotatedClone(void)
{
    TCFbETableEx* Clone = new TCFbETableEx();
    Clone->RotatedAssign(this);
    return Clone;
}

//---------------------------------------------------------------------------
